//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#include "core/capture/capture_base.h"
#include "bodydynamics/capture/capture_inertial_kinematics.h"
#include "bodydynamics/sensor/sensor_inertial_kinematics.h"
#include "core/state_block/state_quaternion.h"
#include "core/state_block/state_block_derived.h"


namespace wolf {

CaptureInertialKinematics::CaptureInertialKinematics(const TimeStamp& _init_ts,
                                                     SensorBasePtr _sensor_ptr,
                                                     const Eigen::Vector9d& _data,    // pbc, vbc, wb
                                                     const Eigen::Matrix3d & _B_I_q,  // Centroidal inertia matrix expressed in body frame
                                                     const Eigen::Vector3d & _B_Lc_m, // Centroidal angular momentum expressed in body frame
                                                     const Vector3d& _bias_pbc) :
                                                CaptureBase("CaptureInertialKinematics",
                                                               _init_ts,
                                                               _sensor_ptr,
                                                               nullptr,
                                                               nullptr,
                                                               std::make_shared<StateParams3>(_bias_pbc, false)),
                                                data_(_data),
                                                B_I_q_(_B_I_q),
                                                B_Lc_m_(_B_Lc_m)
{
    //
}


CaptureInertialKinematics::CaptureInertialKinematics(const TimeStamp& _init_ts,
                                                     SensorBasePtr _sensor_ptr,
                                                     const Eigen::Vector9d& _data,      // pbc, vbc, wb
                                                     const Eigen::Matrix3d & _B_I_q,    // Centroidal inertia matrix expressed in body frame
                                                     const Eigen::Vector3d & _B_Lc_m) : // Centroidal angular momentum expressed in body frame
                                                CaptureBase("CaptureInertialKinematics",
                                                               _init_ts,
                                                               _sensor_ptr,
                                                               nullptr,
                                                               nullptr,
                                                               std::make_shared<StateParams3>(Vector3d::Zero(), false)),
                                                data_(_data),
                                                B_I_q_(_B_I_q),
                                                B_Lc_m_(_B_Lc_m)
{
    //
}

CaptureInertialKinematics::~CaptureInertialKinematics()
{
    //
}

} //namespace wolf
